function [X r]=gram2struct(G,varargin)

% function [X r]=gram2struct(G,...)
% 
% Convert a Gram matrix to a 3-dimensional point set. This assumes
% a protein is what is passed. Optional args are
% 
% 'I' : problem instance is given, sets many of the below options
% 'show' : show a plot of structure or alignment
% 'noshow' : don't plot the structure or alignment
% 'T',T : arg is target structure, do RMSD alignment to it
% 'srmsd' : print RMSD to standard out
% 'bnd',[a b] : arg is start and stop positions
% 'K',K : G is actual a mixed variable, convert according to K
% 'nr',nr : arg is number of residues, for drawing sidechains
% 'rline',w : width of residual line, 0 for off


rot={'Proper';'Reflected'}; 
mcline=2;
mcmark=7;
scline=2;
scmark=7;
rline=0;

show='show';
havestr=0;
d=3;
bnd=0;
srmsd=0;
nr=0;

T=[];
res=[];

i=1;
while i<=length(varargin)
  switch varargin{i}
    case 'show', show='show';
    case 'noshow', show='noshow';
    case 'T', T=varargin{i+1};i=i+1; havestr=1;
    case 'bnd', bnd=varargin{i+1};i=i+1;
    case 'srmsd',srmsd=1; 
    case 'res', res=varargin{i+1};i=i+1;;
    case 'K', 
      K=varargin{i+1}; 
      i=i+1;
      if size(G,2)==1 
        [xL xS]=separate(G,K);
        G=mat(xS);
      end
    case 'E', 
      E=varargin{i+1}; 
      i=i+1;
      [xL xS]=separate(E.xh,E.K);
      G=mat(xS);
      nr = E.nr;
      T = E.T;
      havestr=1;
    case 'I', 
      I=varargin{i+1}; 
      i=i+1;
      nr = I.nr;
      T = I.T;
      havestr=1;
    case 'nr',nr=varargin{i+1};i=i+1;
    case 'rline',rline=varargin{i+1};i=i+1;
    otherwise
      fprintf(1,'Option "%s" not understood; exiting\n',varargin{i});
      X=0; return;
  end
  i=i+1;
end
[m n]=size(G);
[v l]=eig(G);
l=diag(l);
[blah idx]=sort(l,'descend');

X=diag(sqrt(l(idx(1:d)))) * v(:,idx(1:d))';

if bnd
  X=X(:,bnd(1):bnd(2)); 
  if T, T=T(:,bnd(1):bnd(2)); end
  n=bnd(2)-bnd(1)+1;
end
if ~nr, nr=n; end

if d<3, X((d+1):3,:)=0; end

if havestr
   [rr(1) XX{1} YY{1}]=rmsd(X,T);
   [rr(2) XX{2} YY{2}]=rmsd(-X,T);
   [r idx]=min(rr);
   X = XX{idx};
   Y = YY{idx};
end

mcidx = 1:nr;
nmc = nr;
scidx = nr+1:n;
if length(res)>0
  disp('Adjustment');
  mcidx=find(res(2,:)==0);
  scidx=find(res(2,:)==1);
end

if strcmp(show,'show') 
   clf; hold on;
   ckplot3(X(:,mcidx),'b-o','LineWidth',mcline,'MarkerSize',mcmark); 
   if havestr
     ckplot3(Y(:,mcidx),'r-x','LineWidth',mcline,'MarkerSize',mcmark); 
     legend('Gram','Actual');
     ckplot3(Y(:,mcidx(1)),'g-d','LineWidth',mcline,'MarkerSize',mcmark+8); 
     ckplot3(Y(:,mcidx(nmc)),'m-d','LineWidth',mcline,'MarkerSize',mcmark+8); 
     ckplot3(Y(:,nr+1:n),'rx','LineWidth',scline, 'MarkerSize',scmark);
     if rline>0
       for i=1:n
         ckplot3([X(:,i) Y(:,i)],'k--','LineWidth',rline);
       end
     end
   end
   ckplot3(X(:,scidx),'bo','LineWidth',scline,'MarkerSize',scmark); 
   ckplot3(X(:,mcidx(1)),'g-d','LineWidth',mcline,'MarkerSize',mcmark+8); 
   ckplot3(X(:,mcidx(nmc)),'m-d','LineWidth',mcline,'MarkerSize',mcmark+8); 
   
   hold off;
   axis image;
end

if srmsd && havestr
  fprintf(1,'RMSD = %.2f %s\n',r,rot{idx}); 
end
