function E=objective_predict(file,kkr,varargin);
% function E=objective_predict(file,kkr,varargin);
%
% Do prediction of protein structure based on an objective and an
% instance. file is an instance or a .dat file containing an instance.
% kkr is either a whole objective, the linear part of an objective, or
% the parameters used to a feature matrix that will create the linear
% objective.  This function uses active_set() to efficiently handle
% the inequality constraints.


if isstr(file)
  I=instanceR(file,'full');
else
  I=file;
end

E.obj = kkr;

kklen = length(kkr);
if kklen  == I.kdim                     % Learned parameters
  c = [ I.FF * kkr; sp0(I.K.s*I.K.s,1) ];
elseif kklen == size(I.FF,1)            % Specific objective
  c = [ kkr; sp0(I.K.s*I.K.s,1) ];
elseif kklen == I.K.l + I.K.s^2
  c = kkr;
else
  fprintf('Problem with size of parameters/objective\n');
  E=0; return;  
end

% Create an SDP-only inequality problem
cc = linear2sdpobj(c,I.A,I.K);
[AL AS] = separate(I.A, I.K);
[cL cS] = separate( cc, I.K);
K = I.K;
K.l = 0;

[x err Es]=active_set(AS, I.b, cS, K, I.iseq, varargin{:});

E.x = x;
E.err = err;
E.Es = Es;
E.totaltime = Es.totaltime;
