function [xr err] = rankr_approx(A,b,K,x,r)
% function [xr err] = rankr_approx(A,b,K,x,r)
% 
% Return the rank r approximation of a structure. r defaults to 3.
% Also return the error err which is the violation of the structure
% after embedding (nu in the paper)

if nargin<5, r=3; end

[m n]=size(x);
if n==m
  xS = x(:);
else
  [xL xS]=separate(x,K);
end

[AL AS]=separate(A,K);

[qq ll]=eig(mat(xS));
rng = K.s-r+1:K.s;
xSr=vec(qq(:,rng) * ll(rng,rng) * qq(:,rng)');
[inrow incol]=find(AL);
if length(inrow)>0
  slacks = AS(inrow,:) * xSr - b(inrow);
  xLr=slacks(incol);
  xLr(xLr<0)=0;
else
  xLr = [];
end
xr = [xLr; xSr];
err = norm(A*xr - b)/norm(b);
