function Ir=reduce_instance(I)
% function Ir=reduce_instance(I)
%
% Reduce the instance to symmetric vector representation for use with
% objective design.  This must be used to pass an instance into
% objective_design_fixed.m

sqrt2=sqrt(2);
zerodist=1e-1;

attach(I);
m = length(ci);
b = b(1:m);
iseq = iseq(1:m);

n=K.s;
tn=triang(n);
tn1=triang(n-1);                        % Used for the number of dist constraints
sz=[n n];
nn=n*n;
n_eq=sum(iseq);
n_in=m-n_eq;
GT=T'*T;

Amap=triu(svec2mat(1:tn,1));            % Map for quick conversion to svec representation
% Construct AS, use lower triangle only
jdxs=Amap([sub2ind(sz, ci, ci);        % Diag ci
           sub2ind(sz, cj, cj);        % Diag cj
           sub2ind(sz, ci, cj);]);     % Off-diag, upper triang

oo = (1:m)';
idxs = [oo; oo; oo];
mones = ones(m,1);
vals = [mones; mones; -mones*sqrt2];
AS = sparse(idxs,jdxs,vals,m,tn);

AL = sparse(find(~iseq),1:n_in,-ones(n_in,1),m,n_in);
xS=mat2svec(GT);

resid=AS*xS-b;
xL=resid(~iseq);
x=[xL;xS];

% Make adjustments for feasibility and small distances->0
xold=x;
bold=b;
xL(xL<=zerodist)=0;
b=AS*xS+AL*xL;
x=[xL;xS];


% Add centering constraints
aa=sparse(n,n);
for ii=1:n
  aa(:)=0;
  aa(:,ii)=.5;
  aa(ii,:)=.5;
  aa(ii,ii)=1;
  AS(ii+m,:)=mat2svec(aa);
end
AL=[AL; sp0(n,n_in)];
b=[b; zeros(n,1)];
bold=[bold; zeros(n,1)];
iseq(m+1:m+n)=1;
m=m+n;
n_eq=n_eq+n;

[q ll]=eig(GT);
l=diag(ll);

clear QQ;
for i=1:n-3
  QQ(:,i) = mat2svec(q(:,i)*q(:,i)');
end

Ir = struct(...
  'nb',n,...
  'nr',nr,...
  'kdim',kdim,...
  'tn',tn,...
  'm',m,...
  'n_in',n_in,...
  'nzL',nzL,...
  'xL',xL,...
  'x',x,...
  'FF',FF,...
  'Ibar',Ibar,...
  'b',b,...
  'encstr',encstr,...
  'QQ',QQ,...
  'AL',AL,...
  'AS',AS,...
  'cLmap',cLmap,...
  'mcscmap',mcscmap,...
  'res',res,...
  'full', 0,...
  'iseq',iseq,...
  'linidx',linidx,...
  'eqidx',eqidx,...
  'eqdist',eqdist,...
  'inidx',inidx,...
  'indist',indist,...
  'ci', ci,...
  'cj', cj,...
  'F',F...
);
