% function [r XX YY U tx ty]=rmsd(X,Y,show)
%
% Calculate the root mean squared distance between points X and Y (both 3
% by N matrices). r is the RMSD for (X-repmat(tx,1,N)) and
% U*(Y-repmat(ty,1,N)). XX and YY are the best fit coordinates.

function [r XX YY U tx ty]=rmsd(X,Y,show,varargin)
mcline=2;
mcmark=7;
scline=2;
scmark=7;
rline=0;

bnd=0;
nr=0;

if nargin < 3, show=0; end
i=1;
while i<=length(varargin)
  switch varargin{i}
    case 'show', show=1;
    case 'bnd', bnd=varargin{i+1};i=i+1;
    case 'nr',nr=varargin{i+1};i=i+1;
    case 'rline',rline=varargin{i+1};i=i+1;
    otherwise
      fprintf(1,'Option "%s" not understood; exiting\n',varargin{i});
      X=0; return;
  end
  i=i+1;
end

if bnd
  X=X(:,bnd(1):bnd(2)); 
  Y=Y(:,bnd(1):bnd(2)); 
end

[m n]=size(X);
if ~nr, nr=n; end

tx=mean(X,2);
ty=mean(Y,2);
X=X-repmat(tx,1,n);
Y=Y-repmat(ty,1,n);
R=X*Y';
[W,S,V]=svd(R);
s=sign(det(R));
u=eye(m);
u(m,m)=s; % Correct for possible improper rotation
U=W*u*V';
% Analytic RMSD
% r = sqrt(((trace(X'*X)+trace(Y'*Y)) - 2*trace(S))/n);
% r=real(r);
% Explicit RMSD
r =sqrt(sum(sum((U'*X-Y).^2))/n);
XX=U'*X;
YY=Y;

if show
   clf; hold on;
   ckplot3(XX(:,1:nr),'b-o','LineWidth',mcline,'MarkerSize',mcmark); 
   ckplot3(YY(:,1:nr),'r-x','LineWidth',mcline,'MarkerSize',mcmark); 
   if n>nr
     ckplot3(XX(:,nr+1:n),'bo','LineWidth',scline, 'MarkerSize',scmark); 
     ckplot3(YY(:,nr+1:n),'rx','LineWidth',scline, 'MarkerSize',scmark); 
   end
   if rline>0
     for i=1:n
       ckplot3([X(:,i) Y(:,i)],'k-','LineWidth',rline);
     end
   end
   hold off;
end
