function [x y info]=sdpsolver(A,b,c,K,pars)
% function [x y info]=sdpsolver(A,b,c,K,pars)
% 
% Place-holder to allow different sdp solvers to be used.  Defaults to
% csdp but it is also possible to use sedumi.  The other solver
% interfaces are probably suffering from bit rot now.

if nargin < 5,  pars=struct(); pars.solver='csdp'; end

switch pars.solver
  case 'sedumi'
    [x y info]=sedumi(A,b,c,K,pars);
    msg = '';
    if info.pinf,   msg = [msg 'Pinf']; end
    if info.dinf,   msg = [msg 'Dinf']; end
    if info.numerr, msg = sprintf('%sN%d',msg,info.numerr); end
    if strcmp(msg,''), msg = 'OK'; end
    info.msg = msg;

  case 'csdp'
    tic;
    [x y z ecode]=csdp(A,b,c,K,pars);
    info.cpusec=toc;
    info.ecode=ecode;
    info.z=z;
    switch ecode
      case 0,    info.msg = 'OK';
      case 1,    info.msg = 'PInf';
      case 2,    info.msg = 'DInf';
      case 3,    info.msg = 'RedAcc';
      case 4,    info.msg = 'MaxIt';
      case 5,    info.msg = 'Pedge';
      case 6,    info.msg = 'Dedge';
      case 7,    info.msg = 'NoProgr';
      case 8,    info.msg = 'Singul';
      case 9,    info.msg = 'NaN/Inf';
      case 100,  info.msg = 'Matlab';
      otherwise, info.msg = 'BadErr'
    end

  case 'sdpt3'
    [blk,At,C,B,perm] = read_sedumi(A,b,c,K); 
    if isfield(pars,'init')
      X0 = {pars.init.x(1:K.l); mat(pars.init.x(K.l+1:K.l+K.s*K.s))}; 
      Y0 = -pars.init.y;                % Not sure if this is right...
      Z0 = {pars.init.z(1:K.l); mat(pars.init.z(K.l+1:K.l+K.s*K.s))}; 
      [obj,X,Y,Z,info,runhist] = sqlp(blk,At,C,B,pars, X0,Y0,Z0);
    else
      [obj,X,Y,Z,info,runhist] = sqlp(blk,At,C,B,pars);
    end
    [x y info.z] = SDPT3soln_SEDUMIsoln(blk,X,Y,Z,perm); 
    info.cpusec = info.cputime;
    msg = '';
    if info.pinfeas>1e-4, msg = [msg 'Pinf']; end
    if info.dinfeas>1e-4, msg = [msg 'Dinf']; end
    info.msg = msg;
    
  case 'sdplr'
    pars2.forcerank = [1 3];
    pars2.feastol = 1e-2;
    tic;
    [x y info]=sdplr(A,b,c,K,pars2);
    info.cpusec=toc;
    info.msg = '';
    
  otherwise
    fprintf('**ERROR: Unknown solver %s, Exiting\n',solver); 
    
end